from cryptography.hazmat.primitives.asymmetric import ec
from cryptography.hazmat.primitives.serialization import Encoding, PublicFormat
from rest_framework.renderers import BaseRenderer


class PublicKeyPEMRenderer(BaseRenderer):
    """
    A Django REST Framework renderer to serialize public keys as PEM.
    """

    media_type = "application/x-pem-file"
    format = "pem"

    def render(self, data: ec.EllipticCurvePublicKey, *args, **kwargs) -> bytes:
        assert isinstance(data, ec.EllipticCurvePublicKey)
        return data.public_bytes(
            encoding=Encoding.PEM,
            format=PublicFormat.SubjectPublicKeyInfo,
        )
