from django.contrib import admin
from enumfields.admin import EnumFieldListFilter

from arkindex.training.models import Dataset, MetricKey, MetricValue, Model, ModelVersion


class ModelAdmin(admin.ModelAdmin):
    list_display = ('name', 'created', )
    search_fields = ('name', 'description', )
    fields = ('name', 'description', 'public', 'compatible_workers')


class ModelVersionAdmin(admin.ModelAdmin):
    list_display = ('id', 'model', 'tag', 'size', 'state')
    list_filter = ('model__name', ('state', EnumFieldListFilter), )
    fields = ('model', 'parent', 'description', 'state', 'tag', 'hash', 'archive_hash', 'size', 'configuration',)
    readonly_fields = ('hash', 'archive_hash', 'size', )


class MetricValueInline(admin.StackedInline):
    model = MetricValue
    readonly_fields = ('value', 'step')


class MetricKeyAdmin(admin.ModelAdmin):
    list_display = ('name', 'model_version')
    fields = ('name', 'mode', 'model_version')
    list_filter = ('model_version__model',)
    inlines = [MetricValueInline, ]


class DatasetAdmin(admin.ModelAdmin):
    list_display = ('name', 'corpus', 'state')
    list_filter = (('state', EnumFieldListFilter), 'corpus')
    search_fields = ('name', 'description')
    fields = ('id', 'name', 'created', 'updated', 'description', 'corpus', 'creator', 'task', 'sets')
    readonly_fields = ('id', 'created', 'updated', 'task')

    def get_form(self, *args, **kwargs):
        form = super().get_form(*args, **kwargs)
        # Add a help text to mention that the set names should be comma-separated.
        # This is only done here and not through the usual `help_text=…` in the model
        # because this is only relevant to the Django admin and should not appear in
        # DRF serializers or the API docs.
        form.base_fields['sets'].help_text = 'Comma-separated list of set names'
        return form


admin.site.register(Model, ModelAdmin)
admin.site.register(ModelVersion, ModelVersionAdmin)
admin.site.register(MetricKey, MetricKeyAdmin)
admin.site.register(Dataset, DatasetAdmin)
